<?php

namespace Bluesquare\Hooks\Console;

use Illuminate\Console\Command;

#[AsCommand(name: 'hooks:install')]
class InstallCommand extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'hooks:install';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Install Git hooks';

    /**
     * Execute the console command.
     *
     * @return int|null
     */
    public function handle()
    {
        $git_directory = base_path('.git');
        $git_hooks_directory = "{$git_directory}/hooks";

        $this->line("Updating Git hooks...");

        if (! is_dir($git_directory)) {
            $this->error("Could not install hooks: $git_directory is not a Git repository");
            return 1;
        }

        if (! is_dir($git_directory)) {
            if (! mkdir($git_hooks_directory, 0755, true)) {
                $this->error("Could not install hooks: could not create Git hooks directory $git_hooks_directory");
                return 1;
            }

            $this->line("Created Git hooks directory: $git_hooks_directory");
        }

        $files = ['pre-commit'];

        foreach ($files as $file) {
            $git_hook_file = "{$git_hooks_directory}/{$file}";

            if (file_exists($git_hook_file)) {
                $this->line("Git hook file already exists: $git_hook_file. Skipping.");
                continue;
            }

            if (file_put_contents($git_hook_file, file_get_contents(__DIR__.'/../../stubs/'.$file)) === false) {
                $this->error("Could not install hooks: could not create Git hook file $git_hook_file");
                return 1;
            }

            passthru("chmod +x $git_hook_file");

            $this->line("Installed Git hook file: $git_hook_file");
        }

        return 0;
    }
}
